﻿Option Strict Off
Imports System
Imports NXOpen
Imports NXOpen.Drawings
Imports NXOpen.UF

Module PRT_to_PDF

    Dim s As Session = Session.GetSession()
    Dim ufs As UFSession = UFSession.GetUFSession()
    Dim lw As ListingWindow = s.ListingWindow

    Sub Main(ByVal args As String())

        Dim load_options As String = Environ("UGII_LOAD_OPTIONS")
        ufs.Assem.RestoreLoadOptions(load_options)

        Try

            Dim partFlag As Integer = 0
            Dim partCount As Integer = 0
            Dim filename As String = args(0)
            Dim extension As String = Right$(filename, 4)

            lw.Open()

            If extension = ".prt" Or _
            extension = ".PRT" Or _
            extension = ".Prt" Then
                partFlag = open_part_file(filename)
                partCount = ufs.Part.AskNumParts()
            End If

            If partFlag > 0 Then
                ' Some parts failed to open.
                ' Take appropriate action here
                '-----------------------------
            Else
                If partCount > 0 Then
                    process_each_drawing(s.Parts.Display(), filename)
                End If
            End If

            ' Close any open part files 

            If partCount > 0 Then
                s.Parts.CloseAll(BasePart.CloseModified.CloseModified, Nothing)
            End If

            ufs.Undo.DeleteAllMarks()

        Catch ex As Exception
            Console.OpenStandardOutput()
            Console.WriteLine("115 " & ex.ToString)
            Console.WriteLine()
        End Try

    End Sub

    Sub process_each_drawing(ByVal thePart As Part, ByVal fileName As String)

        Dim workPart As Part = thePart

        Try

            If thePart.Tag = Tag.Null Then Return

            Dim drawingSheets As DrawingSheet() = thePart.DrawingSheets.ToArray
            Dim mySheet As DrawingSheet = Nothing
            Dim partName As String = thePart.Leaf.ToString()

            For Each mySheet In drawingSheets

                mySheet.Open()

                Dim pdf_output_name As String = ""
                pdf_output_name = fileName.ToLower()
                pdf_output_name = pdf_output_name.Replace(".prt", "")
                Dim sheetName As String = mySheet.Name.ToLower()

                If drawingSheets.Length() > 1 Then
                    pdf_output_name = String.Concat(pdf_output_name, "_", sheetName, ".pdf")
                Else
                    pdf_output_name = String.Concat(pdf_output_name, ".pdf")
                End If

                Dim printPDFBuilder1 As PrintPDFBuilder
                printPDFBuilder1 = workPart.PlotManager.CreatePrintPdfbuilder()

                Dim dwgUnits As DrawingSheet.Unit = mySheet.Units
                If dwgUnits = DrawingSheet.Unit.Inches Then printPDFBuilder1.Units = PrintPDFBuilder.UnitsOption.English
                If dwgUnits = DrawingSheet.Unit.Millimeters Then printPDFBuilder1.Units = PrintPDFBuilder.UnitsOption.Metric

                printPDFBuilder1.Scale = 1.0
                printPDFBuilder1.Action = PrintPDFBuilder.ActionOption.New
                'printPDFBuilder1.Action = PrintPDFBuilder.ActionOption.Native
                printPDFBuilder1.Append = False
                printPDFBuilder1.Colors = PrintPDFBuilder.Color.BlackOnWhite
                printPDFBuilder1.Widths = PrintPDFBuilder.Width.StandardWidths
                printPDFBuilder1.Size = PrintPDFBuilder.SizeOption.ScaleFactor
                printPDFBuilder1.XDimension = mySheet.Length()
                printPDFBuilder1.YDimension = mySheet.Height()
                printPDFBuilder1.RasterImages = True
                printPDFBuilder1.ImageResolution = PrintPDFBuilder.ImageResolutionOption.Medium
                printPDFBuilder1.ShadedGeometry = True

                Dim nXObject1 As NXObject
                Dim sheets1(0) As NXObject
                sheets1(0) = mySheet

                printPDFBuilder1.SourceBuilder.SetSheets(sheets1)
                printPDFBuilder1.Filename = pdf_output_name

                Try
                    nXObject1 = printPDFBuilder1.Commit()
                Catch ex As Exception
                    lw.WriteLine("205 " & ex.ToString)
                Finally
                    printPDFBuilder1.Destroy()
                End Try

            Next

        Catch ex As Exception
            lw.WriteLine("215 " & ex.ToString)
        End Try

    End Sub

    Function open_part_file(ByVal fileName As String) As Integer

        Dim loadStatus As NXOpen.PartLoadStatus = Nothing

        Dim currentPart As Part = s.Parts.OpenBaseDisplay(fileName, loadStatus)
        If loadStatus.NumberUnloadedParts < 1 Then
            '     lw.WriteLine("   Processing Part File: " & fileName)
        Else
            For inx As Integer = 0 To loadStatus.NumberUnloadedParts - 1
                lw.WriteLine(loadStatus.GetStatus(inx).ToString())
                Dim errno As Integer = CInt(loadStatus.GetStatus(inx))
                Dim errmsg As String = ""
                ufs.UF.GetFailMessage(errno, errmsg)
                lw.WriteLine("Error: " & errmsg & " in: " & fileName)
                lw.WriteLine("  ")
            Next
        End If

        Return loadStatus.NumberUnloadedParts()

    End Function

End Module

